@@ -1,7 +1,8 @@
 from z3c.form import field
 
+from five import grok
+
 from plone.z3cform import layout
-from plone.app.z3cform.wysiwyg import WysiwygFieldWidget
 
 from plone.app.registry.browser.controlpanel import RegistryEditForm
 from plone.app.registry.browser.controlpanel import ControlPanelFormWrapper
@@ -11,13 +12,12 @@ from ipnext.site.editablefooter import _
 
 
 class FooterControlPanelForm(RegistryEditForm):
+    grok.context(IFooterSettings)
+
     schema = IFooterSettings
     label = _(u"Footer control panel")
 
-    # Replace the standard field widget with a nicer one
-    fields = field.Fields(IFooterSettings)
-    fields['footer'].widgetFactory = WysiwygFieldWidget
-
+    #fields = field.Fields(IFooterSettings)
     def update(self):
         super(RegistryEditForm, self).update()
 
