@@ -1,13 +1,18 @@
 from zope.interface import Interface
 from zope import schema
 
+from plone.directives import form
+
+from plone.app.z3cform.wysiwyg import WysiwygFieldWidget
+
 from ipnext.site.editablefooter.config import TMPL_YEAR
 from ipnext.site.editablefooter import _
 
 
-class IFooterSettings(Interface):
+class IFooterSettings(form.Schema):
     """Describes registry records
     """
+    form.widget(footer=WysiwygFieldWidget)
     footer = schema.Text(
         title=_(u"Footer text"),
         description=_(
@@ -15,9 +20,11 @@ class IFooterSettings(Interface):
         ),
         required=False,
     )
-    
+
 class IEditableFooterLayer(Interface):
     """A layer specific for this add-on product.
 
     This interface is referred in browserlayers.xml.
     """
+
+
